PowerOfTwo32

Struct PowerOfTwo32 

pub struct PowerOfTwo32 { /* private fields */ }
Represents a power of two, as a 32-bit value, which includes zero.

Implementations

Source

impl PowerOfTwo32

pub const ZERO: Self

Represents PowerOfTwo32 zero.

pub const unsafe fn new_unchecked(value: u32) -> Self

Creates a new PowerOfTwo32 from a 32-bit value.

Safety

This function does not validate value. It is up to the caller to ensure that its value is a power of two.

pub const fn new(value: u32) -> Result<Self, PowerOfTwoError>

Creates a new PowerOfTwo32 from a 32-bit value.

Errors

Returns PowerOfTwoError::NotAPowerOfTwo if value is not a power of two.

pub fn next(self) -> Self

Returns the next power of two.

Panics

Panics in debug mode if the next power of two is greater than u32::MAX. In release mode it wraps to zero.

pub const fn value(self) -> u32

Returns the underlying value of the PowerOfTwo32.

pub const fn as_usize(self) -> usize

Returns the underlying value as usize.

Panics

Panics if usize is smaller than u32.