pub struct PowerOfTwo64 { /* private fields */ }Expand description
Represents a power of two, as a 64-bit value, which includes zero.
Implementations
Sourceimpl PowerOfTwo64
impl PowerOfTwo64
Sourcepub const ZERO: Self
pub const ZERO: Self
Represents PowerOfTwo64 zero.
Sourcepub const unsafe fn new_unchecked(value: u64) -> Self
pub const unsafe fn new_unchecked(value: u64) -> Self
Creates a new PowerOfTwo64 from a 64-bit value.
Safety
This function does not validate value. It is up to the
caller to ensure that its value is a power of two.
Sourcepub const fn new(value: u64) -> Result<Self, PowerOfTwoError>
pub const fn new(value: u64) -> Result<Self, PowerOfTwoError>
Creates a new PowerOfTwo64 from a 64-bit value.
Errors
Returns PowerOfTwoError::NotAPowerOfTwo if value is not a power of two.
Sourcepub const fn value(self) -> u64
pub const fn value(self) -> u64
Returns the underlying value of the PowerOfTwo64.