pub struct PowerOfTwo32 { /* private fields */ }Expand description
Represents a power of two, as a 32-bit value, which includes zero.
Implementations
Sourceimpl PowerOfTwo32
impl PowerOfTwo32
Sourcepub const ZERO: Self
pub const ZERO: Self
Represents PowerOfTwo32 zero.
Sourcepub const unsafe fn new_unchecked(value: u32) -> Self
pub const unsafe fn new_unchecked(value: u32) -> Self
Creates a new PowerOfTwo32 from a 32-bit value.
Safety
This function does not validate value. It is up to the
caller to ensure that its value is a power of two.
Sourcepub const fn new(value: u32) -> Result<Self, PowerOfTwoError>
pub const fn new(value: u32) -> Result<Self, PowerOfTwoError>
Creates a new PowerOfTwo32 from a 32-bit value.
Errors
Returns PowerOfTwoError::NotAPowerOfTwo if value is not a power of two.
Sourcepub const fn value(self) -> u32
pub const fn value(self) -> u32
Returns the underlying value of the PowerOfTwo32.